@@ -12,5 +12,7 @@ pub use aead::*;
 pub use kdf::*;
 pub use key_exchange::*;
 pub use keys::*;
+pub use protocol::*;
 pub use signature::*;
+pub use storage::*;
 pub use traits::*;
